checkCommonMistakes property
Whether to check for common mistakes in the email, such as ".con" instead of ".com".
Implementation
final bool checkCommonMistakes;
Whether to check for common mistakes in the email, such as ".con" instead of ".com".
final bool checkCommonMistakes;