preventConsecutiveDots property
Whether to prevent consecutive dots in the email address. For example, "user..name@example.com" will be considered invalid if this is true.
Implementation
final bool preventConsecutiveDots;
Whether to prevent consecutive dots in the email address. For example, "user..name@example.com" will be considered invalid if this is true.
final bool preventConsecutiveDots;