PasswordValidator class

Constructors

PasswordValidator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
minLength ↔ int
getter/setter pair
requireDigit ↔ bool
getter/setter pair
requireLowercase ↔ bool
getter/setter pair
requireSymbol ↔ bool
getter/setter pair
requireUppercase ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

custom({bool? requireDigit, bool? requireUppercase, bool? requireLowercase, bool? requireSymbol, int? minLength}) → PasswordValidator
Allows custom validation rules for digits, symbols, etc.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setStrength(PasswordStrength strength) → PasswordValidator
Sets the strength of the password using the PasswordStrength
toString() → String
A string representation of this object.
inherited
validate(String password) → String?
Validates the password based on the configured rules.

Operators

operator ==(Object other) → bool
The equality operator.
inherited