CountryCode enum
Values
- Afghanistan → const CountryCode
-
const CountryCode('93') - Albania → const CountryCode
-
const CountryCode('355') - Algeria → const CountryCode
-
const CountryCode('213') - AmericanSamoa → const CountryCode
-
const CountryCode('1-684') - Andorra → const CountryCode
-
const CountryCode('376') - Angola → const CountryCode
-
const CountryCode('244') - Anguilla → const CountryCode
-
const CountryCode('1-264') - Antarctica → const CountryCode
-
const CountryCode('672') - AntiguaAndBarbuda → const CountryCode
-
const CountryCode('1-268') - Argentina → const CountryCode
-
const CountryCode('54') - Armenia → const CountryCode
-
const CountryCode('374') - Aruba → const CountryCode
-
const CountryCode('297') - Australia → const CountryCode
-
const CountryCode('61') - Austria → const CountryCode
-
const CountryCode('43') - Azerbaijan → const CountryCode
-
const CountryCode('994') - Bahamas → const CountryCode
-
const CountryCode('1-242') - Bahrain → const CountryCode
-
const CountryCode('973') - Bangladesh → const CountryCode
-
const CountryCode('880') - Barbados → const CountryCode
-
const CountryCode('1-246') - Belarus → const CountryCode
-
const CountryCode('375') - Belgium → const CountryCode
-
const CountryCode('32') - Belize → const CountryCode
-
const CountryCode('501') - Benin → const CountryCode
-
const CountryCode('229') - Bermuda → const CountryCode
-
const CountryCode('1-441') - Bhutan → const CountryCode
-
const CountryCode('975') - Bolivia → const CountryCode
-
const CountryCode('591') - BosniaAndHerzegovina → const CountryCode
-
const CountryCode('387') - Botswana → const CountryCode
-
const CountryCode('267') - Brazil → const CountryCode
-
const CountryCode('55') - BritishIndianOceanTerritory → const CountryCode
-
const CountryCode('246') - BritishVirginIslands → const CountryCode
-
const CountryCode('1-284') - Brunei → const CountryCode
-
const CountryCode('673') - Bulgaria → const CountryCode
-
const CountryCode('359') - BurkinaFaso → const CountryCode
-
const CountryCode('226') - Burundi → const CountryCode
-
const CountryCode('257') - Cambodia → const CountryCode
-
const CountryCode('855') - Cameroon → const CountryCode
-
const CountryCode('237') - Canada → const CountryCode
-
const CountryCode('1') - CapeVerde → const CountryCode
-
const CountryCode('238') - CaymanIslands → const CountryCode
-
const CountryCode('1-345') - CentralAfricanRepublic → const CountryCode
-
const CountryCode('236') - Chad → const CountryCode
-
const CountryCode('235') - Chile → const CountryCode
-
const CountryCode('56') - China → const CountryCode
-
const CountryCode('86') - ChristmasIsland → const CountryCode
-
const CountryCode('61') - CocosIslands → const CountryCode
-
const CountryCode('61') - Colombia → const CountryCode
-
const CountryCode('57') - Comoros → const CountryCode
-
const CountryCode('269') - CookIslands → const CountryCode
-
const CountryCode('682') - CostaRica → const CountryCode
-
const CountryCode('506') - Croatia → const CountryCode
-
const CountryCode('385') - Cuba → const CountryCode
-
const CountryCode('53') - Curacao → const CountryCode
-
const CountryCode('599') - Cyprus → const CountryCode
-
const CountryCode('357') - CzechRepublic → const CountryCode
-
const CountryCode('420') - DemocraticRepublicOfTheCongo → const CountryCode
-
const CountryCode('243') - Denmark → const CountryCode
-
const CountryCode('45') - Djibouti → const CountryCode
-
const CountryCode('253') - Dominica → const CountryCode
-
const CountryCode('1-767') - DominicanRepublic → const CountryCode
-
const CountryCode('1-809, 1-829, 1-849') - EastTimor → const CountryCode
-
const CountryCode('670') - Ecuador → const CountryCode
-
const CountryCode('593') - Egypt → const CountryCode
-
const CountryCode('20') - ElSalvador → const CountryCode
-
const CountryCode('503') - EquatorialGuinea → const CountryCode
-
const CountryCode('240') - Eritrea → const CountryCode
-
const CountryCode('291') - Estonia → const CountryCode
-
const CountryCode('372') - Ethiopia → const CountryCode
-
const CountryCode('251') - FalklandIslands → const CountryCode
-
const CountryCode('500') - FaroeIslands → const CountryCode
-
const CountryCode('298') - Fiji → const CountryCode
-
const CountryCode('679') - Finland → const CountryCode
-
const CountryCode('358') - France → const CountryCode
-
const CountryCode('33') - FrenchPolynesia → const CountryCode
-
const CountryCode('689') - Gabon → const CountryCode
-
const CountryCode('241') - Gambia → const CountryCode
-
const CountryCode('220') - Georgia → const CountryCode
-
const CountryCode('995') - Germany → const CountryCode
-
const CountryCode('49') - Ghana → const CountryCode
-
const CountryCode('233') - Gibraltar → const CountryCode
-
const CountryCode('350') - Greece → const CountryCode
-
const CountryCode('30') - Greenland → const CountryCode
-
const CountryCode('299') - Grenada → const CountryCode
-
const CountryCode('1-473') - Guam → const CountryCode
-
const CountryCode('1-671') - Guatemala → const CountryCode
-
const CountryCode('502') - Guernsey → const CountryCode
-
const CountryCode('44-1481') - Guinea → const CountryCode
-
const CountryCode('224') - GuineaBissau → const CountryCode
-
const CountryCode('245') - Guyana → const CountryCode
-
const CountryCode('592') - Haiti → const CountryCode
-
const CountryCode('509') - Honduras → const CountryCode
-
const CountryCode('504') - HongKong → const CountryCode
-
const CountryCode('852') - Hungary → const CountryCode
-
const CountryCode('36') - Iceland → const CountryCode
-
const CountryCode('354') - India → const CountryCode
-
const CountryCode('91') - Indonesia → const CountryCode
-
const CountryCode('62') - Iran → const CountryCode
-
const CountryCode('98') - Iraq → const CountryCode
-
const CountryCode('964') - Ireland → const CountryCode
-
const CountryCode('353') - IsleOfMan → const CountryCode
-
const CountryCode('44-1624') - Israel → const CountryCode
-
const CountryCode('972') - Italy → const CountryCode
-
const CountryCode('39') - IvoryCoast → const CountryCode
-
const CountryCode('225') - Jamaica → const CountryCode
-
const CountryCode('1-876') - Japan → const CountryCode
-
const CountryCode('81') - Jersey → const CountryCode
-
const CountryCode('44-1534') - Jordan → const CountryCode
-
const CountryCode('962') - Kazakhstan → const CountryCode
-
const CountryCode('7') - Kenya → const CountryCode
-
const CountryCode('254') - Kiribati → const CountryCode
-
const CountryCode('686') - KoreaNorth → const CountryCode
-
const CountryCode('850') - KoreaSouth → const CountryCode
-
const CountryCode('82') - Kuwait → const CountryCode
-
const CountryCode('965') - Kyrgyzstan → const CountryCode
-
const CountryCode('996') - Laos → const CountryCode
-
const CountryCode('856') - Latvia → const CountryCode
-
const CountryCode('371') - Lebanon → const CountryCode
-
const CountryCode('961') - Lesotho → const CountryCode
-
const CountryCode('266') - Liberia → const CountryCode
-
const CountryCode('231') - Libya → const CountryCode
-
const CountryCode('218') - Liechtenstein → const CountryCode
-
const CountryCode('423') - Lithuania → const CountryCode
-
const CountryCode('370') - Luxembourg → const CountryCode
-
const CountryCode('352') - Macau → const CountryCode
-
const CountryCode('853') - Madagascar → const CountryCode
-
const CountryCode('261') - Malawi → const CountryCode
-
const CountryCode('265') - Malaysia → const CountryCode
-
const CountryCode('60') - Maldives → const CountryCode
-
const CountryCode('960') - Mali → const CountryCode
-
const CountryCode('223') - Malta → const CountryCode
-
const CountryCode('356') - MarshallIslands → const CountryCode
-
const CountryCode('692') - Martinique → const CountryCode
-
const CountryCode('596') - Mauritania → const CountryCode
-
const CountryCode('222') - Mauritius → const CountryCode
-
const CountryCode('230') - Mayotte → const CountryCode
-
const CountryCode('262') - Mexico → const CountryCode
-
const CountryCode('52') - Micronesia → const CountryCode
-
const CountryCode('691') - Moldova → const CountryCode
-
const CountryCode('373') - Monaco → const CountryCode
-
const CountryCode('377') - Mongolia → const CountryCode
-
const CountryCode('976') - Montenegro → const CountryCode
-
const CountryCode('382') - Montserrat → const CountryCode
-
const CountryCode('1-664') - Morocco → const CountryCode
-
const CountryCode('212') - Mozambique → const CountryCode
-
const CountryCode('258') - Namibia → const CountryCode
-
const CountryCode('264') - Nauru → const CountryCode
-
const CountryCode('674') - Nepal → const CountryCode
-
const CountryCode('977') - Netherlands → const CountryCode
-
const CountryCode('31') - NewCaledonia → const CountryCode
-
const CountryCode('687') - NewZealand → const CountryCode
-
const CountryCode('64') - Nicaragua → const CountryCode
-
const CountryCode('505') - Niger → const CountryCode
-
const CountryCode('227') - Nigeria → const CountryCode
-
const CountryCode('234') - Niue → const CountryCode
-
const CountryCode('683') - NorfolkIsland → const CountryCode
-
const CountryCode('672') - NorthMacedonia → const CountryCode
-
const CountryCode('389') - NorthernMarianaIslands → const CountryCode
-
const CountryCode('1-670') - Norway → const CountryCode
-
const CountryCode('47') - Oman → const CountryCode
-
const CountryCode('968') - Pakistan → const CountryCode
-
const CountryCode('92') - Palau → const CountryCode
-
const CountryCode('680') - Panama → const CountryCode
-
const CountryCode('507') - PapuaNewGuinea → const CountryCode
-
const CountryCode('675') - Paraguay → const CountryCode
-
const CountryCode('595') - Peru → const CountryCode
-
const CountryCode('51') - Philippines → const CountryCode
-
const CountryCode('63') - PitcairnIslands → const CountryCode
-
const CountryCode('64') - Poland → const CountryCode
-
const CountryCode('48') - Portugal → const CountryCode
-
const CountryCode('351') - PuertoRico → const CountryCode
-
const CountryCode('1-787, 1-939') - Rwanda → const CountryCode
-
const CountryCode('250') - Reunion → const CountryCode
-
const CountryCode('262') - Romania → const CountryCode
-
const CountryCode('40') - Russia → const CountryCode
-
const CountryCode('7') - SaintBarthelemy → const CountryCode
-
const CountryCode('590') - SaintHelena → const CountryCode
-
const CountryCode('290') - SaintKittsAndNevis → const CountryCode
-
const CountryCode('1-869') - SaintLucia → const CountryCode
-
const CountryCode('1-758') - SaintMartin → const CountryCode
-
const CountryCode('590') - SaintPierreAndMiquelon → const CountryCode
-
const CountryCode('508') - SaintVincentAndTheGrenadines → const CountryCode
-
const CountryCode('1-784') - Samoa → const CountryCode
-
const CountryCode('685') - SanMarino → const CountryCode
-
const CountryCode('378') - SaoTomeAndPrincipe → const CountryCode
-
const CountryCode('239') - SaudiArabia → const CountryCode
-
const CountryCode('966') - Senegal → const CountryCode
-
const CountryCode('221') - Serbia → const CountryCode
-
const CountryCode('381') - Seychelles → const CountryCode
-
const CountryCode('248') - SierraLeone → const CountryCode
-
const CountryCode('232') - Singapore → const CountryCode
-
const CountryCode('65') - SintMaarten → const CountryCode
-
const CountryCode('1-721') - Slovakia → const CountryCode
-
const CountryCode('421') - Slovenia → const CountryCode
-
const CountryCode('386') - SolomonIslands → const CountryCode
-
const CountryCode('677') - Somalia → const CountryCode
-
const CountryCode('252') - SouthAfrica → const CountryCode
-
const CountryCode('27') - SouthGeorgiaAndTheSouthSandwichIslands → const CountryCode
-
const CountryCode('500') - Spain → const CountryCode
-
const CountryCode('34') - SriLanka → const CountryCode
-
const CountryCode('94') - Sudan → const CountryCode
-
const CountryCode('249') - Suriname → const CountryCode
-
const CountryCode('597') - SvalbardAndJanMayen → const CountryCode
-
const CountryCode('47') - Swaziland → const CountryCode
-
const CountryCode('268') - Sweden → const CountryCode
-
const CountryCode('46') - Switzerland → const CountryCode
-
const CountryCode('41') - Syria → const CountryCode
-
const CountryCode('963') - Taiwan → const CountryCode
-
const CountryCode('886') - Tajikistan → const CountryCode
-
const CountryCode('992') - Tanzania → const CountryCode
-
const CountryCode('255') - Thailand → const CountryCode
-
const CountryCode('66') - Togo → const CountryCode
-
const CountryCode('228') - Tokelau → const CountryCode
-
const CountryCode('690') - Tonga → const CountryCode
-
const CountryCode('676') - TrinidadAndTobago → const CountryCode
-
const CountryCode('1-868') - Tunisia → const CountryCode
-
const CountryCode('216') - Turkey → const CountryCode
-
const CountryCode('90') - Turkmenistan → const CountryCode
-
const CountryCode('993') - Tuvalu → const CountryCode
-
const CountryCode('688') - Uganda → const CountryCode
-
const CountryCode('256') - Ukraine → const CountryCode
-
const CountryCode('380') - UnitedArabEmirates → const CountryCode
-
const CountryCode('971') - UnitedKingdom → const CountryCode
-
const CountryCode('44') - UnitedStates → const CountryCode
-
const CountryCode('1') - Uruguay → const CountryCode
-
const CountryCode('598') - Uzbekistan → const CountryCode
-
const CountryCode('998') - Vanuatu → const CountryCode
-
const CountryCode('678') - VaticanCity → const CountryCode
-
const CountryCode('39') - Venezuela → const CountryCode
-
const CountryCode('58') - Vietnam → const CountryCode
-
const CountryCode('84') - WallisAndFutuna → const CountryCode
-
const CountryCode('681') - WesternSahara → const CountryCode
-
const CountryCode('212') - Yemen → const CountryCode
-
const CountryCode('967') - Zambia → const CountryCode
-
const CountryCode('260') - Zimbabwe → const CountryCode
-
const CountryCode('263')
Properties
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CountryCode> - A constant List of the values in this enum, in order of their declaration.