EmailValidationOptions class

Constructors

EmailValidationOptions({bool checkFormat = true, bool preventConsecutiveDots = true, bool preventMultipleAtSymbols = true, bool checkCommonMistakes = true, bool preventDisposableEmails = true, bool checkEndsWithDot = true, int minLength = 5})
Constructor to set default validation options

Properties

checkCommonMistakes bool
Whether to check for common mistakes in the email, such as ".con" instead of ".com".
final
checkEndsWithDot bool
Whether to ensure the email does not end with a dot.
final
checkFormat bool
Whether to validate the email format against a standard email regex pattern.
final
hashCode int
The hash code for this object.
no setterinherited
minLength int
Minimum length required for the email address. Default is 5 characters.
final
preventConsecutiveDots bool
Whether to prevent consecutive dots in the email address. For example, "user..name@example.com" will be considered invalid if this is true.
final
preventDisposableEmails bool
Whether to block disposable email domains such as "mailinator.com" or "10minutemail.com".
final
preventMultipleAtSymbols bool
Whether to prevent multiple '@' symbols in the email address. For example, "user@@example.com" will be considered invalid if this is true.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited