EmailValidator class
Constructors
- EmailValidator({required EmailValidationOptions options})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → EmailValidationOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String email) → String? - Validates the email based on user-specified options
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited