PhoneValidator class

Validator class for phone numbers.

Constructors

PhoneValidator(PhoneValidationOptions options)
Constructor to initialize the validator with custom options.

Properties

hashCode int
The hash code for this object.
no setterinherited
options PhoneValidationOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String phoneNumber) String?
Validates a phone number based on the provided options.

Operators

operator ==(Object other) bool
The equality operator.
inherited